@@ -99,7 +99,7 @@ scrui_response (GtkDialog *dialog,
 	    gtk_widget_hide ((GtkWidget*)dialog);
         break;
 	case GTK_RESPONSE_HELP:
-	    gn_load_help ("gnopernicus-screen-review");
+	    gn_load_help ("gnopernicus-screenreview-prefs");
 	break;
         default:
 	    gtk_widget_hide ((GtkWidget*)dialog);
