@@ -219,7 +219,7 @@ spui_voice_add_modify_new_speaker_settings_get (void)
     
     if (!spui_speech_voice_add_modify.w_voice_setting_add_modify)
 	return NULL;
-	    
+    	    
     new_settings = spconf_speaker_settings_new ();
     new_settings->volume 		= CHECK_RANGE_OF_VALUE (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_volume)), MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
     new_settings->rate   		= CHECK_RANGE_OF_VALUE (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_rate)), MIN_SPEECH_RATE, MAX_SPEECH_RATE);
@@ -348,14 +348,14 @@ spui_voice_add_modify_speaker_values_modify (SpeakerSettings *settings)
     spui_voice_add_modify_combo_list_set (tmp, spui_speech_voice_add_modify.cb_engine_voice);
     spconf_list_for_combo_free (tmp);
 
-
+    
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_volume), 	(gdouble)settings->volume);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_rate), 	(gdouble)settings->rate);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_pitch), 	(gdouble)settings->pitch);
     gtk_range_set_value (GTK_RANGE (spui_speech_voice_add_modify.hs_voice_volume), settings->volume);
     gtk_range_set_value (GTK_RANGE (spui_speech_voice_add_modify.hs_voice_rate), 	settings->rate);
     gtk_range_set_value (GTK_RANGE (spui_speech_voice_add_modify.hs_voice_pitch), 	settings->pitch);
-    gtk_entry_set_text  (GTK_ENTRY (spui_speech_voice_add_modify.et_gnopernicus_voice), settings->gnopernicus_speaker);
+    gtk_entry_set_text  (GTK_ENTRY (spui_speech_voice_add_modify.et_gnopernicus_voice), _(settings->gnopernicus_speaker));
     gtk_entry_set_text  (GTK_ENTRY (GTK_COMBO (spui_speech_voice_add_modify.cb_engine_voice)->entry), settings->voice_name_descr);
     gtk_entry_set_text  (GTK_ENTRY (GTK_COMBO (spui_speech_voice_add_modify.cb_engine_driver)->entry), settings->driver_name_descr);
     
@@ -598,7 +598,7 @@ spui_voice_add_modify_response (GtkDialog *dialog,
 	    sp_changes_activable = FALSE;
         break;
 	case GTK_RESPONSE_HELP: 
-	    gn_load_help ("gnopernicus-speech-settings");
+	    gn_load_help ("gnopernicus-speech-prefs");
 	    return;
 	break;
         default:
@@ -679,6 +679,18 @@ spui_voice_add_modify_handlers_set  (GladeXML *xml)
 
 }
 
+static void
+spui_voice_add_modify_set_ranges ()
+{
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_volume), MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_rate), MIN_SPEECH_RATE, MAX_SPEECH_RATE);
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_pitch), MIN_SPEECH_PITCH, MAX_SPEECH_PITCH);
+	
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_add_modify.hs_voice_volume), MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_add_modify.hs_voice_rate), MIN_SPEECH_RATE, MAX_SPEECH_RATE);
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_add_modify.hs_voice_pitch), MIN_SPEECH_PITCH, MAX_SPEECH_PITCH);
+}
+
 static gboolean 
 spui_voice_add_modify_load (GtkWidget *parent_window)
 {         
@@ -698,6 +710,7 @@ spui_voice_add_modify_load (GtkWidget *parent_window)
     else
 	gtk_widget_show (spui_speech_voice_add_modify.w_voice_setting_add_modify);
     
+    spui_voice_add_modify_set_ranges ();    
     return TRUE;
 }
 
@@ -824,7 +837,7 @@ spui_voice_relative_response (GtkDialog *dialog,
 	case GTK_RESPONSE_OK: 
         break;
 	case GTK_RESPONSE_HELP: 
-	    gn_load_help ("gnopernicus-speech-settings");
+	    gn_load_help ("gnopernicus-speech-prefs");
 	    return;
 	break;
 	default:
@@ -1365,7 +1378,7 @@ spui_voice_absolute_response (GtkDialog *dialog,
 	case GTK_RESPONSE_OK: 
         break;
 	case GTK_RESPONSE_HELP: 
-	    gn_load_help ("gnopernicus-speech-settings");
+	    gn_load_help ("gnopernicus-speech-prefs");
 	    return;
 	break;
 	default:
@@ -1393,6 +1406,36 @@ spui_voice_absolute_handlers_set  (GladeXML *xml)
     spui_speech_voice_absolute.ck_abs_rate 	   	= glade_xml_get_widget (xml, "ck_abs_rate_active");
     spui_speech_voice_absolute.ck_abs_volume 	   	= glade_xml_get_widget (xml, "ck_abs_volume_active");    
 
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_pitch),
+				    MIN_SPEECH_PITCH, MAX_SPEECH_PITCH);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_pitch),
+				    DEFAULT_SPEECH_PITCH);
+
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_rate),
+				    MIN_SPEECH_RATE, MAX_SPEECH_RATE);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_rate),
+				    DEFAULT_SPEECH_RATE);
+
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_volume),
+				    MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spui_speech_voice_absolute.sp_abs_volume),
+				    DEFAULT_SPEECH_VOLUME);
+
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_absolute.hs_abs_pitch),
+				    MIN_SPEECH_PITCH, MAX_SPEECH_PITCH);
+    gtk_range_set_value (GTK_RANGE (spui_speech_voice_absolute.hs_abs_pitch),
+				    DEFAULT_SPEECH_PITCH);
+
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_absolute.hs_abs_rate),
+				    MIN_SPEECH_RATE, MAX_SPEECH_RATE);
+    gtk_range_set_value (GTK_RANGE (spui_speech_voice_absolute.hs_abs_rate),
+				    DEFAULT_SPEECH_RATE);
+
+    gtk_range_set_range (GTK_RANGE (spui_speech_voice_absolute.hs_abs_volume),
+				    MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
+    gtk_range_set_value (GTK_RANGE (spui_speech_voice_absolute.hs_abs_volume),
+				    DEFAULT_SPEECH_VOLUME);
+
     g_object_set_data (G_OBJECT (spui_speech_voice_absolute.ck_abs_volume), 
 			"abs_volume", glade_xml_get_widget (xml, "lb_abs_volume"));
     g_object_set_data (G_OBJECT (spui_speech_voice_absolute.ck_abs_volume), 
@@ -1856,7 +1899,7 @@ spui_voice_settings_response (GtkDialog *dialog,
 	}
         break;
 	case GTK_RESPONSE_HELP: 
-	    gn_load_help ("gnopernicus-speech-settings");
+	    gn_load_help ("gnopernicus-speech-prefs");
 	break;
 	default:
 	    gtk_widget_hide ((GtkWidget*)dialog);
